@@ -220,7 +220,7 @@ def format_autolab_json(data, indent=None):
 
             d = {'passed': pass_}
             if not pass_:
-                d['hints'] = val['stderr']
+                d['hint'] = val['stderr']
             rs[item_name] = d
 
 
